# Translation of Source Code for DocFX Websites

This tool translates DocFX's Markdown and Yaml source code into foreign languages, preserving markup sintax.

Powered by [Yandex.Translate](http://translate.yandex.com)